@@ -20,7 +20,8 @@ import os
 import pathlib
 import sys
 import time
-import typing
+from typing import Optional
+from typing import Union
 
 import east_asian_spacing as chws
 from chws_tool.config import GoogleFontsConfig
@@ -29,25 +30,28 @@ logger = logging.getLogger("add_chws")
 
 
 async def add_chws_async(
-    input: typing.Union[str, os.PathLike],
-    output: typing.Union[str, os.PathLike],
+    input: Union[str, os.PathLike],
+    output: Optional[Union[str, os.PathLike]] = None,
     **kwargs,
-) -> typing.Optional[pathlib.Path]:
+) -> Optional[pathlib.Path]:
     """Add OpenType chws/vchw features to a font.
 
-    Returns the path of the output font,
-    or `None` if the feature is not applicable to the font.
-
-    `**kwargs` are optional. They are passed directly to
-    `east_asian_spacing.Builder.save()`."""
+    Args:
+        input: The path of the input font.
+        output: The path or the directory of the output font.
+          When omitted, the input font is updated.
+        kwargs: They are passed directly to
+          `east_asian_spacing.Builder.save()`.
 
+    Returns:
+        The path of the output font.
+        `None` if the feature is not applicable to the font.
+    """
     builder = chws.Builder(input, config=GoogleFontsConfig.default)
-    await builder.build()
-    if not builder.has_spacings:
+    output_path = await builder.build_and_save(output, **kwargs)
+    if not output_path:
         logger.info('Skipped saving due to no changes: "%s"', input)
         return None
-
-    output_path = builder.save(output, **kwargs)
     logger.info("%s ==> %s", input, output_path)
 
     await builder.test()
@@ -56,26 +60,42 @@ async def add_chws_async(
 
 
 def add_chws(
-    input: typing.Union[str, os.PathLike],
-    output: typing.Union[str, os.PathLike],
+    input: Union[str, os.PathLike],
+    output: Optional[Union[str, os.PathLike]] = None,
     **kwargs,
-) -> typing.Optional[pathlib.Path]:
+) -> Optional[pathlib.Path]:
+    """Add OpenType chws/vchw features to a font.
+
+    Args:
+        input: The path of the input font.
+        output: The path or the directory of the output font.
+          When omitted, the input font is updated.
+        kwargs: They are passed directly to
+          `east_asian_spacing.Builder.save()`.
+
+    Returns:
+        The path of the output font.
+        `None` if the feature is not applicable to the font.
+    """
     loop = asyncio.get_event_loop()
     return loop.run_until_complete(add_chws_async(input, output, **kwargs))
 
 
-def _dump_font_names(inputs):
+def _print_font_names(inputs):
     for input in inputs:
         font = chws.Font.load(input)
         fonts = font.fonts_in_collection if font.is_collection else (font,)
         for font in fonts:
-            print(font.debug_name(1))
+            # Prefer Typographic Family name (16) if the font has it.
+            # Otherwise fallback to Font Family name (1).
+            # https://docs.microsoft.com/en-us/typography/opentype/spec/name#name-ids
+            print(font.debug_name(16, 1))
 
 
 async def main_async() -> None:
     parser = argparse.ArgumentParser()
     parser.add_argument("inputs", nargs="+")
-    parser.add_argument("--dump-name", help="dump font names", action="store_true")
+    parser.add_argument("--print-name", help="print font names", action="store_true")
     parser.add_argument("-g", "--glyph-out", help="output glyph list")
     parser.add_argument(
         "-o", "--output", default="build", type=pathlib.Path, help="output directory"
@@ -95,8 +115,8 @@ async def main_async() -> None:
     # Expand directories.
     inputs = chws.Builder.expand_paths(args.inputs)
 
-    if args.dump_name:
-        _dump_font_names(inputs)
+    if args.print_name:
+        _print_font_names(inputs)
         return
 
     if args.glyph_out:
