@@ -65,41 +65,30 @@ def _get_factory_by_name() -> typing.Dict[
         "Dela Gothic One": use_upem_no_vert,
         "DotGothic16": allow_monospace_ascii,
         "Hachi Maru Pop": default,
+        "Hina Mincho": has_no_vert_pairs,
+        "Kaisei Decol": default,
+        "Kaisei HarunoUmi": default,
+        "Kaisei Opti": default,
+        "Kaisei Tokumin": default,
         "Kiwi Maru": default,
-        "Kiwi Maru Light": default,
-        "Kiwi Maru Medium": default,
+        "Klee One": default,
         "MotoyaLCedar": allow_monospace_ascii,
         "MotoyaLMaru": allow_monospace_ascii,
         "Mplus 1p": default,
-        "Mplus 1p Black": default,
         "Mplus 1p Bold": default,
-        "Mplus 1p ExtraBold": default,
-        "Mplus 1p Light": default,
-        "Mplus 1p Medium": default,
-        "Mplus 1p Thin": default,
         "Otomanopee One": has_no_pairs,
         "Rounded Mplus 1c": default,
-        "Rounded Mplus 1c Black": default,
         "Rounded Mplus 1c Bold": default,
-        "Rounded Mplus 1c ExtraBold": default,
-        "Rounded Mplus 1c Light": default,
-        "Rounded Mplus 1c Medium": default,
-        "Rounded Mplus 1c Thin": default,
         "New Tegomin": default,
         "Palette Mosaic": not_applicable,
         "Potta One": default,
+        "Rampart One": default,
         "Reggae One": default,
         "RocknRoll One": default,
         "Sawarabi Gothic": default,
         "Sawarabi Mincho": default,
         "Shippori Mincho": default,
         "Shippori Mincho B1": default,
-        "Shippori Mincho B1 ExtraBold": default,
-        "Shippori Mincho B1 Medium": default,
-        "Shippori Mincho B1 SemiBold": default,
-        "Shippori Mincho ExtraBold": default,
-        "Shippori Mincho Medium": default,
-        "Shippori Mincho SemiBold": default,
         "Stick": default,
         "Train One": default,
         "Yomogi": allow_monospace_ascii_no_vert,
@@ -112,34 +101,26 @@ def _get_factory_by_name() -> typing.Dict[
         "Dokdo": has_no_pairs,
         "East Sea Dokdo": has_no_pairs,
         "Gaegu": has_no_pairs,
-        "Gaegu Light": has_no_pairs,
         "Gamja Flower": has_no_pairs,
         "Gothic A1": has_no_pairs,
-        "Gothic A1 Black": has_no_pairs,
-        "Gothic A1 ExtraBold": has_no_pairs,
-        "Gothic A1 ExtraLight": has_no_pairs,
-        "Gothic A1 Light": has_no_pairs,
-        "Gothic A1 Medium": has_no_pairs,
-        "Gothic A1 SemiBold": has_no_pairs,
-        "Gothic A1 Thin": has_no_pairs,
+        "Gowun Batang": has_no_pairs,
+        "Gowun Dodum": has_no_pairs,
         "Gugi": has_no_pairs,
+        "Hahmlet": has_no_pairs,
         "Hi Melody": has_no_pairs,
+        "IBM Plex Sans KR": default,
         "Jua": has_no_pairs,
         "Kirang Haerang": has_no_pairs,
         "Nanum Brush Script": not_applicable,
         "NanumGothic": not_applicable,
-        "NanumGothicExtraBold": not_applicable,
         "NanumGothicCoding": has_no_pairs,
         "NanumMyeongjo": has_no_pairs,
-        "NanumMyeongjoExtraBold": has_no_pairs,
         "Nanum Pen": not_applicable,
         "Poor Story": has_no_pairs,
         "Single Day": has_no_pairs,
         "Song Myung": has_no_pairs,
         "Stylish": has_no_pairs,
         "Sunflower": has_no_pairs,
-        "Sunflower Light": has_no_pairs,
-        "Sunflower Medium": has_no_pairs,
         "Yeon Sung": has_no_pairs,
         # ZHS
         "Liu Jian Mao Cao": has_no_pairs,
